@@ -4,7 +4,7 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 use Carp;
 use Scalar::Util qw( set_prototype );
@@ -44,7 +44,7 @@ sub import {
         };
     };
 
-    $target ||= __PACKAGE__."::container::".$caller;
+    $target //= __PACKAGE__."::container::".$caller;
 
     my $spec = Resource::Silo::Metadata->new($target);
     $metadata{$target} = $spec;
@@ -444,11 +444,6 @@ either initialized, or overridden.
 
 See L<Resource::Silo::Container/lock>.
 
-=head3 ignore_cache => 0 | 1
-
-If set, don't cache resource, always create a fresh one instead.
-See also L<Resource::Silo::Container/fresh>.
-
 =head3 preload => 0 | 1
 
 If set, try loading the resource when C<silo-E<gt>ctl-E<gt>preload> is called.
@@ -645,6 +640,10 @@ This software is still in beta stage. Its interface is still evolving.
 
 =item * Version 0.09 brings a breaking change that forbids forward dependencies.
 
+=item * Version 0.14 removes the C<ignore_cache> flag
+as it doesn't seem to have compelling use cases
+while complicating the implementation.
+
 =item * Forced re-exporting of C<silo> was probably a bad idea
 and should have been left as an exercise to the user.
 
