@@ -2,7 +2,7 @@ package Resource::Silo::Container;
 
 use strict;
 use warnings;
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 =head1 NAME
 
@@ -63,7 +63,8 @@ sub BUILD {
 sub DEMOLISH {
     my $self = shift;
     delete $active_instances{ refaddr $self };
-    $self->ctl->cleanup;
+    $self->ctl->cleanup
+        if $self->{-spec};
 };
 
 # As container instances inside the silo() function will be available forever,
@@ -94,21 +95,15 @@ Example:
     silo->ctl->override( dbh => $fake_database_connection );
     silo->ctl->lock; # forbid instantiating new resources
 
-Returns a facade object.
-
-B<NOTE> Such object contains a weak reference to the parent object
-and thus must not be saved anywhere, lest you be surprised.
-Use it and discard immediately.
+Returns a facade object referencing the original container.
 
 =cut
 
 sub ctl {
     my $self = shift;
-    my $facade = bless \$self, 'Resource::Silo::Container::Dashboard';
-    weaken $$facade;
-    confess "Attempt to close over nonexistent value"
-        unless $$facade;
-    return $facade;
+    return bless \$self, 'Resource::Silo::Container::Dashboard';
+    # 'Clever' weaken-ing code was here
+    # Please don't do this again, it's unnecessary
 };
 
 # Instantiate resource $name with argument $argument.
@@ -136,9 +131,6 @@ sub _silo_instantiate_res {
             and !$spec->{derived}
             and !$self->{-override}{$name};
 
-    self->_silo_unexpected_dep($name)
-        if ($self->{-allow} && !$self->{-allow}{$name});
-
     # Detect circular dependencies
     my $key = $name . (length $arg ? "/$arg" : '');
     if ($self->{-pending}{$key}) {
@@ -168,7 +160,7 @@ sub _silo_cleanup_res {
     # TODO Do we need to validate arguments here?
     my $spec = $self->{-spec}{resource}{$name};
 
-    return if $opt{fork} and $spec->{fork_safe};
+    return if $opt{fork} and not $opt{force} and $spec->{fork_safe};
 
     # NOTE Be careful! cleanup must never ever die!
 
@@ -176,9 +168,7 @@ sub _silo_cleanup_res {
     if (!$self->{-override}{$name}) {
         # 1) skip resources that have overrides
         # 2) if we're in "no pid" mode, use fork_cleanup if available
-        $action = $opt{fork}
-            && $spec->{fork_cleanup}
-            || $spec->{cleanup};
+        $action = $opt{fork} ? $spec->{fork_cleanup} : $spec->{cleanup};
     };
     my $known = $self->{-cache}{$name};
 
@@ -207,20 +197,13 @@ sub _silo_cleanup_res {
 sub _silo_make_accessor {
     my ($name, $spec) = @_;
 
-    if ($spec->{ignore_cache}) {
-        return sub {
-            my ($self, $arg) = @_;
-            return $self->_silo_instantiate_res($name, $arg);
-        };
-    };
-
     return sub {
         my ($self, $arg) = @_;
 
         # If there was a fork, flush cache
-        if ($self->{-pid} != $$) {
-            $self->ctl->cleanup;
-            $self->{-pid} = $$;
+        if ($self->{-pid} != (my $pid = $$)) {
+            $self->ctl->_cleanup( fork => 1 );
+            $self->{-pid} = $pid;
         };
 
         # We must check dependencies even before going to the cache
@@ -414,7 +397,7 @@ sub cleanup {
     # Don't give the user access to options (yet)
 
     my @opt;
-    push @opt, fork => 1 if $$ != $$self->{-pid};
+    push @opt, fork => 1, force => 1 if $$ != $$self->{-pid};
 
     $self->_cleanup(@opt);
 }
